@@ -4,17 +4,17 @@
  * For LGPL see License.txt in the project root for license information.
  * For commercial licenses see https://www.tiny.cloud/
  *
- * Version: 5.8.2 (2021-06-23)
+ * Version: 5.10.9 (2023-11-15)
  */
 (function () {
     'use strict';
 
-    var global = tinymce.util.Tools.resolve('tinymce.PluginManager');
+    var global$1 = tinymce.util.Tools.resolve('tinymce.PluginManager');
 
-    var global$1 = tinymce.util.Tools.resolve('tinymce.util.Tools');
+    var global = tinymce.util.Tools.resolve('tinymce.util.Tools');
 
     var html2bbcode = function (s) {
-      s = global$1.trim(s);
+      s = global.trim(s);
       var rep = function (re, str) {
         s = s.replace(re, str);
       };
@@ -58,7 +58,7 @@
       return s;
     };
     var bbcode2html = function (s) {
-      s = global$1.trim(s);
+      s = global.trim(s);
       var rep = function (re, str) {
         s = s.replace(re, str);
       };
@@ -79,7 +79,7 @@
     };
 
     function Plugin () {
-      global.add('bbcode', function (editor) {
+      global$1.add('bbcode', function (editor) {
         editor.on('BeforeSetContent', function (e) {
           e.content = bbcode2html(e.content);
         });
