@@ -4,7 +4,7 @@
  * For LGPL see License.txt in the project root for license information.
  * For commercial licenses see https://www.tiny.cloud/
  *
- * Version: 5.8.2 (2021-06-23)
+ * Version: 5.10.9 (2023-11-15)
  */
 (function () {
     'use strict';
@@ -23,7 +23,7 @@
       };
     };
 
-    var global = tinymce.util.Tools.resolve('tinymce.PluginManager');
+    var global$4 = tinymce.util.Tools.resolve('tinymce.PluginManager');
 
     var __assign = function () {
       __assign = Object.assign || function __assign(t) {
@@ -38,13 +38,13 @@
       return __assign.apply(this, arguments);
     };
 
-    var global$1 = tinymce.util.Tools.resolve('tinymce.util.Tools');
+    var global$3 = tinymce.util.Tools.resolve('tinymce.util.Tools');
 
     var global$2 = tinymce.util.Tools.resolve('tinymce.html.DomParser');
 
-    var global$3 = tinymce.util.Tools.resolve('tinymce.html.Node');
+    var global$1 = tinymce.util.Tools.resolve('tinymce.html.Node');
 
-    var global$4 = tinymce.util.Tools.resolve('tinymce.html.Serializer');
+    var global = tinymce.util.Tools.resolve('tinymce.html.Serializer');
 
     var shouldHideInSourceView = function (editor) {
       return editor.getParam('fullpage_hide_in_source_view');
@@ -74,14 +74,14 @@
       return editor.getParam('protect');
     };
 
-    var parseHeader = function (head) {
+    var parseHeader = function (editor, head) {
       return global$2({
         validate: false,
         root_name: '#document'
-      }).parse(head, { format: 'xhtml' });
+      }, editor.schema).parse(head, { format: 'xhtml' });
     };
     var htmlToData = function (editor, head) {
-      var headerFragment = parseHeader(head);
+      var headerFragment = parseHeader(editor, head);
       var data = {};
       var elm, matches;
       var getAttr = function (elm, name) {
@@ -106,7 +106,7 @@
       if (elm && elm.firstChild) {
         data.title = elm.firstChild.value;
       }
-      global$1.each(headerFragment.getAll('meta'), function (meta) {
+      global$3.each(headerFragment.getAll('meta'), function (meta) {
         var name = meta.attr('name');
         var httpEquiv = meta.attr('http-equiv');
         var matches;
@@ -124,7 +124,7 @@
         data.langcode = getAttr(elm, 'lang') || getAttr(elm, 'xml:lang');
       }
       data.stylesheets = [];
-      global$1.each(headerFragment.getAll('link'), function (link) {
+      global$3.each(headerFragment.getAll('link'), function (link) {
         if (link.attr('rel') === 'stylesheet') {
           data.stylesheets.push(link.attr('href'));
         }
@@ -140,7 +140,7 @@
       return data;
     };
     var dataToHtml = function (editor, data, head) {
-      var headElement, elm, value;
+      var headElement, elm;
       var dom = editor.dom;
       var setAttr = function (elm, name, value) {
         elm.attr(name, value ? value : undefined);
@@ -152,11 +152,11 @@
           headElement.append(node);
         }
       };
-      var headerFragment = parseHeader(head);
+      var headerFragment = parseHeader(editor, head);
       headElement = headerFragment.getAll('head')[0];
       if (!headElement) {
         elm = headerFragment.getAll('html')[0];
-        headElement = new global$3('head', 1);
+        headElement = new global$1('head', 1);
         if (elm.firstChild) {
           elm.insert(headElement, elm.firstChild, true);
         } else {
@@ -165,12 +165,12 @@
       }
       elm = headerFragment.firstChild;
       if (data.xml_pi) {
-        value = 'version="1.0"';
+        var value = 'version="1.0"';
         if (data.docencoding) {
           value += ' encoding="' + data.docencoding + '"';
         }
         if (elm.type !== 7) {
-          elm = new global$3('xml', 7);
+          elm = new global$1('xml', 7);
           headerFragment.insert(elm, headerFragment.firstChild, true);
         }
         elm.value = value;
@@ -180,7 +180,7 @@
       elm = headerFragment.getAll('#doctype')[0];
       if (data.doctype) {
         if (!elm) {
-          elm = new global$3('#doctype', 10);
+          elm = new global$1('#doctype', 10);
           if (data.xml_pi) {
             headerFragment.insert(elm, headerFragment.firstChild);
           } else {
@@ -192,14 +192,14 @@
         elm.remove();
       }
       elm = null;
-      global$1.each(headerFragment.getAll('meta'), function (meta) {
+      global$3.each(headerFragment.getAll('meta'), function (meta) {
         if (meta.attr('http-equiv') === 'Content-Type') {
           elm = meta;
         }
       });
       if (data.docencoding) {
         if (!elm) {
-          elm = new global$3('meta', 1);
+          elm = new global$1('meta', 1);
           elm.attr('http-equiv', 'Content-Type');
           elm.shortEnded = true;
           addHeadNode(elm);
@@ -211,16 +211,16 @@
       elm = headerFragment.getAll('title')[0];
       if (data.title) {
         if (!elm) {
-          elm = new global$3('title', 1);
+          elm = new global$1('title', 1);
           addHeadNode(elm);
         } else {
           elm.empty();
         }
-        elm.append(new global$3('#text', 3)).value = data.title;
+        elm.append(new global$1('#text', 3)).value = data.title;
       } else if (elm) {
         elm.remove();
       }
-      global$1.each('keywords,description,author,copyright,robots'.split(','), function (name) {
+      global$3.each('keywords,description,author,copyright,robots'.split(','), function (name) {
         var nodes = headerFragment.getAll('meta');
         var i, meta;
         var value = data[name];
@@ -236,7 +236,7 @@
           }
         }
         if (value) {
-          elm = new global$3('meta', 1);
+          elm = new global$1('meta', 1);
           elm.attr('name', name);
           elm.attr('content', value);
           elm.shortEnded = true;
@@ -244,14 +244,14 @@
         }
       });
       var currentStyleSheetsMap = {};
-      global$1.each(headerFragment.getAll('link'), function (stylesheet) {
+      global$3.each(headerFragment.getAll('link'), function (stylesheet) {
         if (stylesheet.attr('rel') === 'stylesheet') {
           currentStyleSheetsMap[stylesheet.attr('href')] = stylesheet;
         }
       });
-      global$1.each(data.stylesheets, function (stylesheet) {
+      global$3.each(data.stylesheets, function (stylesheet) {
         if (!currentStyleSheetsMap[stylesheet]) {
-          elm = new global$3('link', 1);
+          elm = new global$1('link', 1);
           elm.attr({
             rel: 'stylesheet',
             text: 'text/css',
@@ -262,7 +262,7 @@
         }
         delete currentStyleSheetsMap[stylesheet];
       });
-      global$1.each(currentStyleSheetsMap, function (stylesheet) {
+      global$3.each(currentStyleSheetsMap, function (stylesheet) {
         stylesheet.remove();
       });
       elm = headerFragment.getAll('body')[0];
@@ -288,7 +288,7 @@
       if (!headElement.firstChild) {
         headElement.remove();
       }
-      var html = global$4({
+      var html = global({
         validate: false,
         indent: true,
         indent_before: 'head,html,body,meta,title,script,link,style',
@@ -362,21 +362,21 @@
         initialData: initialData,
         onSubmit: function (api) {
           var nuData = api.getData();
-          var headHtml = dataToHtml(editor, global$1.extend(data, nuData), headState.get());
+          var headHtml = dataToHtml(editor, global$3.extend(data, nuData), headState.get());
           headState.set(headHtml);
           api.close();
         }
       });
     };
 
-    var register = function (editor, headState) {
+    var register$1 = function (editor, headState) {
       editor.addCommand('mceFullPageProperties', function () {
         open(editor, headState);
       });
     };
 
     var protectHtml = function (protect, html) {
-      global$1.each(protect, function (pattern) {
+      global$3.each(protect, function (pattern) {
         html = html.replace(pattern, function (str) {
           return '<!--mce:protected ' + escape(str) + '-->';
         });
@@ -389,7 +389,7 @@
       });
     };
 
-    var each = global$1.each;
+    var each = global$3.each;
     var low = function (s) {
       return s.replace(/<\/?[A-Z]+/g, function (a) {
         return a.toLowerCase();
@@ -409,7 +409,7 @@
         return;
       }
       if (content.length === 0 && !evt.source_view) {
-        content = global$1.trim(headState.get()) + '\n' + global$1.trim(content) + '\n' + global$1.trim(footState.get());
+        content = global$3.trim(headState.get()) + '\n' + global$3.trim(content) + '\n' + global$3.trim(footState.get());
       }
       content = content.replace(/<(\/?)BODY/gi, '<$1body');
       startPos = content.indexOf('<body');
@@ -420,13 +420,13 @@
         if (endPos === -1) {
           endPos = content.length;
         }
-        evt.content = global$1.trim(content.substring(startPos + 1, endPos));
+        evt.content = global$3.trim(content.substring(startPos + 1, endPos));
         footState.set(low(content.substring(endPos)));
       } else {
         headState.set(getDefaultHeader(editor));
         footState.set('\n</body>\n</html>');
       }
-      var headerFragment = parseHeader(headState.get());
+      var headerFragment = parseHeader(editor, headState.get());
       each(headerFragment.getAll('style'), function (node) {
         if (node.firstChild) {
           styles += node.firstChild.value;
@@ -449,12 +449,12 @@
         styleElm.appendChild(document.createTextNode(styles));
       }
       var currentStyleSheetsMap = {};
-      global$1.each(headElm.getElementsByTagName('link'), function (stylesheet) {
+      global$3.each(headElm.getElementsByTagName('link'), function (stylesheet) {
         if (stylesheet.rel === 'stylesheet' && stylesheet.getAttribute('data-mce-fullpage')) {
           currentStyleSheetsMap[stylesheet.href] = stylesheet;
         }
       });
-      global$1.each(headerFragment.getAll('link'), function (stylesheet) {
+      global$3.each(headerFragment.getAll('link'), function (stylesheet) {
         var href = stylesheet.attr('href');
         if (!href) {
           return true;
@@ -469,7 +469,7 @@
         }
         delete currentStyleSheetsMap[href];
       });
-      global$1.each(currentStyleSheetsMap, function (stylesheet) {
+      global$3.each(currentStyleSheetsMap, function (stylesheet) {
         stylesheet.parentNode.removeChild(stylesheet);
       });
     };
@@ -501,7 +501,7 @@
     };
     var handleGetContent = function (editor, head, foot, evt) {
       if (evt.format === 'html' && !evt.selection && (!evt.source_view || !shouldHideInSourceView(editor))) {
-        evt.content = unprotectHtml(global$1.trim(head) + '\n' + global$1.trim(evt.content) + '\n' + global$1.trim(foot));
+        evt.content = unprotectHtml(global$3.trim(head) + '\n' + global$3.trim(evt.content) + '\n' + global$3.trim(foot));
       }
     };
     var setup = function (editor, headState, footState) {
@@ -513,7 +513,7 @@
       });
     };
 
-    var register$1 = function (editor) {
+    var register = function (editor) {
       editor.ui.registry.addButton('fullpage', {
         tooltip: 'Metadata and document properties',
         icon: 'document-properties',
@@ -531,10 +531,10 @@
     };
 
     function Plugin () {
-      global.add('fullpage', function (editor) {
+      global$4.add('fullpage', function (editor) {
         var headState = Cell(''), footState = Cell('');
-        register(editor, headState);
-        register$1(editor);
+        register$1(editor, headState);
+        register(editor);
         setup(editor, headState, footState);
       });
     }
