@@ -1,4 +1,4 @@
-import { FieldProcessorAdt, FieldSchema } from '@ephox/boulder';
+import { FieldProcessor, FieldSchema } from '@ephox/boulder';
 import { Fun } from '@ephox/katamari';
 
 import * as Fields from '../../data/Fields';
@@ -9,4 +9,4 @@ export default [
   FieldSchema.option('disableClass'),
   Fields.onHandler('onDisabled'),
   Fields.onHandler('onEnabled')
-] as FieldProcessorAdt[];
+] as FieldProcessor[];
