@@ -1,4 +1,4 @@
-import { FieldSchema, FieldProcessorAdt } from '@ephox/boulder';
+import { FieldSchema, FieldProcessor } from '@ephox/boulder';
 
 import { Composing } from '../api/behaviour/Composing';
 import { Receiving } from '../api/behaviour/Receiving';
@@ -8,7 +8,7 @@ import { SketchBehaviours } from '../api/component/SketchBehaviours';
 
 // TODO: Roll this back into Fields at some point
 // Unfortunately there appears to be a cyclical dependency or something that's preventing it, but for now this will do as it's home
-const sandboxFields = (): FieldProcessorAdt[] => [
+const sandboxFields = (): FieldProcessor[] => [
   FieldSchema.defaulted('sandboxClasses', [ ]),
   SketchBehaviours.field('sandboxBehaviours', [ Composing, Receiving, Sandboxing, Representing ])
 ];
