@@ -1,4 +1,4 @@
-import { ValueSchema } from '@ephox/boulder';
+import { StructureSchema } from '@ephox/boulder';
 
 import HotspotAnchor from './HotspotAnchor';
 import MakeshiftAnchor from './MakeshiftAnchor';
@@ -6,12 +6,12 @@ import NodeAnchor from './NodeAnchor';
 import SelectionAnchor from './SelectionAnchor';
 import SubmenuAnchor from './SubmenuAnchor';
 
-export default ValueSchema.choose(
-  'anchor', {
+export default StructureSchema.choose(
+  'type', {
     selection: SelectionAnchor,
     node: NodeAnchor,
     hotspot: HotspotAnchor,
     submenu: SubmenuAnchor,
     makeshift: MakeshiftAnchor
   }
-);
\ No newline at end of file
+);
