@@ -48,7 +48,8 @@ module.exports = function (grunt) {
     pkg: packageData,
 
     shell: {
-      tsc: { command: 'tsc -b' }
+      tsc: { command: 'tsc -b' },
+      moxiedoc: { command: 'moxiedoc "src/core/main/ts" -t tinymcenext --fail-on-warning --dry' }
     },
 
     eslint: {
@@ -185,7 +186,11 @@ module.exports = function (grunt) {
             comments: 'all',
             ascii_only: true
           },
-          ie8: true
+          compress: {
+            passes: 2,
+            // TINY-7720: Disable merge_vars as it has a bug that causes errors on IE 11
+            merge_vars: false
+          }
         },
         core: {
           files: [
@@ -237,7 +242,6 @@ module.exports = function (grunt) {
       {plugins: () => gruntWebPack.allPluginDemos(plugins)},
       {themes: () => {
         gruntWebPack.allThemeDemos(themes);
-        gruntWebPack.allComponentDemos(themes);
       }},
       gruntUtils.generate(plugins, 'plugin', (name) => () => gruntWebPack.createPlugin(name) ),
       gruntUtils.generate(themes, 'theme', (name) => () => gruntWebPack.createTheme(name) )
@@ -436,6 +440,7 @@ module.exports = function (grunt) {
               'modules/*/.stylelintignore',
               'modules/*/.stylelintrc',
               'modules/tinymce/tools',
+              'modules/tinymce/copyright-header.js',
               '.yarnrc',
               'LICENSE.TXT',
               'README.md',
@@ -555,12 +560,14 @@ module.exports = function (grunt) {
               return new Buffer(JSON.stringify(json, null, '\t'));
             }
 
+            const keywords = ['wysiwyg', 'tinymce', 'richtext', 'javascript', 'html', 'text', 'rich editor', 'rich text editor', 'rte', 'rich text', 'contenteditable', 'editing']
+
             zip.addData('bower.json', jsonToBuffer({
               'name': 'tinymce',
               'description': 'Web based JavaScript HTML WYSIWYG editor control.',
               'license': 'LGPL-2.1',
-              'keywords': ['editor', 'wysiwyg', 'tinymce', 'richtext', 'javascript', 'html'],
-              'homepage': 'http://www.tinymce.com',
+              'keywords': keywords,
+              'homepage': 'https://www.tiny.cloud/',
               'ignore': ['README.md', 'composer.json', 'package.json', '.npmignore', 'CHANGELOG.md']
             }));
 
@@ -569,14 +576,16 @@ module.exports = function (grunt) {
               'version': packageData.version,
               'repository': {
                 'type': 'git',
-                'url': 'https://github.com/tinymce/tinymce-dist.git'
+                'url': 'https://github.com/tinymce/tinymce.git',
+                'directory': 'modules/tinymce'
               },
               'description': 'Web based JavaScript HTML WYSIWYG editor control.',
               'author': 'Tiny Technologies, Inc',
               'main': 'tinymce.js',
               'types': 'tinymce.d.ts',
               'license': 'LGPL-2.1',
-              'keywords': ['editor', 'wysiwyg', 'tinymce', 'richtext', 'javascript', 'html'],
+              'keywords': keywords,
+              'homepage': 'https://www.tiny.cloud/',
               'bugs': { 'url': 'https://github.com/tinymce/tinymce/issues' }
             }));
 
@@ -585,8 +594,8 @@ module.exports = function (grunt) {
               'version': packageData.version,
               'description': 'Web based JavaScript HTML WYSIWYG editor control.',
               'license': ['LGPL-2.1-only'],
-              'keywords': ['editor', 'wysiwyg', 'tinymce', 'richtext', 'javascript', 'html'],
-              'homepage': 'http://www.tinymce.com',
+              'keywords': keywords,
+              'homepage': 'https://www.tiny.cloud/',
               'type': 'component',
               'extra': {
                 'component': {
@@ -670,9 +679,9 @@ module.exports = function (grunt) {
           releaseNotes: 'Release notes for my package.',
           summary: 'TinyMCE is a platform independent web based Javascript HTML WYSIWYG editor ' +
           'control released as Open Source under LGPL by Tiny Technologies, Inc.',
-          projectUrl: 'http://www.tinymce.com/',
-          iconUrl: 'http://www.tinymce.com/favicon.ico',
-          licenseUrl: 'http://www.tinymce.com/license',
+          projectUrl: 'https://www.tiny.cloud/',
+          iconUrl: 'https://www.tiny.cloud/favicon-32x32.png',
+          licenseUrl: 'https://www.tiny.cloud/license',
           requireLicenseAcceptance: true,
           tags: 'Editor TinyMCE HTML HTMLEditor',
           excludes: [
@@ -714,9 +723,9 @@ module.exports = function (grunt) {
           description: 'This package has been deprecated use https://www.nuget.org/packages/TinyMCE/',
           releaseNotes: 'This package has been deprecated use https://www.nuget.org/packages/TinyMCE/',
           summary: 'This package has been deprecated use https://www.nuget.org/packages/TinyMCE/',
-          projectUrl: 'http://www.tinymce.com/',
-          iconUrl: 'http://www.tinymce.com/favicon.ico',
-          licenseUrl: 'http://www.tinymce.com/license',
+          projectUrl: 'https://www.tiny.cloud/',
+          iconUrl: 'https://www.tiny.cloud/favicon-32x32.png',
+          licenseUrl: 'https://www.tiny.cloud/license',
           requireLicenseAcceptance: true,
           tags: 'Editor TinyMCE HTML HTMLEditor',
           excludes: [
