@@ -5,7 +5,8 @@
  * For commercial licenses see https://www.tiny.cloud/
  */
 
-import { Obj } from '@ephox/katamari';
+import { Fun, Obj } from '@ephox/katamari';
+
 import Tools from '../util/Tools';
 
 export type SchemaType = 'html4' | 'html5' | 'html5-strict';
@@ -31,6 +32,7 @@ export interface SchemaSettings {
   valid_styles?: string | Record<string, string>;
   verify_html?: boolean;
   whitespace_elements?: string;
+  padd_empty_block_inline_children?: boolean;
 }
 
 export interface Attribute {
@@ -63,6 +65,7 @@ export interface ElementRule {
   paddEmpty?: boolean;
   removeEmpty?: boolean;
   removeEmptyAttrs?: boolean;
+  paddInEmptyBlock?: boolean;
 }
 
 export interface SchemaElement extends ElementRule {
@@ -75,17 +78,17 @@ export interface SchemaMap { [name: string]: {} }
 export interface SchemaRegExpMap { [name: string]: RegExp }
 
 interface Schema {
-  children: Record<string, {}>;
+  children: Record<string, SchemaMap>;
   elements: Record<string, SchemaElement>;
-  getValidStyles: () => SchemaMap;
-  getValidClasses: () => SchemaMap;
+  getValidStyles: () => Record<string, string[]> | undefined;
+  getValidClasses: () => Record<string, SchemaMap> | undefined;
   getBlockElements: () => SchemaMap;
-  getInvalidStyles: () => SchemaMap;
+  getInvalidStyles: () => Record<string, SchemaMap> | undefined;
   getShortEndedElements: () => SchemaMap;
   getTextBlockElements: () => SchemaMap;
   getTextInlineElements: () => SchemaMap;
   getBoolAttrs: () => SchemaMap;
-  getElementRule: (name: string) => SchemaElement;
+  getElementRule: (name: string) => SchemaElement | undefined;
   getSelfClosingElements: () => SchemaMap;
   getNonEmptyElements: () => SchemaMap;
   getMoveCaretBeforeOnEnterElements: () => SchemaMap;
@@ -123,6 +126,19 @@ const split = (items: string, delim?: string): string[] => {
   return items ? items.split(delim || ' ') : [];
 };
 
+const createMap = (defaultValue?: string, extendWith?: SchemaMap): SchemaMap => {
+  const value = makeMap(defaultValue, ' ', makeMap(defaultValue.toUpperCase(), ' '));
+  return extend(value, extendWith);
+};
+
+// A curated list using the textBlockElements map and parts of the blockElements map from the schema
+// TODO: TINY-8728 Investigate if the extras can be added directly to the default text block elements
+export const getTextRootBlockElements = (schema: Schema): SchemaMap =>
+  createMap(
+    'td th li dt dd figcaption caption details summary',
+    schema.getTextBlockElements()
+  );
+
 /**
  * Builds a schema lookup table
  *
@@ -434,7 +450,7 @@ const Schema = (settings?: SchemaSettings): Schema => {
   const customElementsMap = {}, specialElements = {} as SchemaRegExpMap;
 
   // Creates an lookup table map object for the specified option or the default value
-  const createLookupTable = (option: string, defaultValue?: string, extendWith?: string) => {
+  const createLookupTable = (option: string, defaultValue?: string, extendWith?: SchemaMap): SchemaMap => {
     let value = settings[option];
 
     if (!value) {
@@ -442,8 +458,7 @@ const Schema = (settings?: SchemaSettings): Schema => {
       value = mapCache[option];
 
       if (!value) {
-        value = makeMap(defaultValue, ' ', makeMap(defaultValue.toUpperCase(), ' '));
-        value = extend(value, extendWith);
+        value = createMap(defaultValue, extendWith);
 
         mapCache[option] = value;
       }
@@ -487,7 +502,7 @@ const Schema = (settings?: SchemaSettings): Schema => {
   const blockElementsMap = createLookupTable('block_elements', 'hr table tbody thead tfoot ' +
     'th tr td li ol ul caption dl dt dd noscript menu isindex option ' +
     'datalist select optgroup figcaption details summary', textBlockElementsMap);
-  const textInlineElementsMap = createLookupTable('text_inline_elements', 'span strong b em i font strike u var cite ' +
+  const textInlineElementsMap = createLookupTable('text_inline_elements', 'span strong b em i font s strike u var cite ' +
     'dfn code mark q sup sub samp');
 
   each((settings.special || 'script noscript iframe noframes noembed title style textarea xmp').split(' '), (name) => {
@@ -782,8 +797,20 @@ const Schema = (settings?: SchemaSettings): Schema => {
     // Add default alt attribute for images, removed since alt="" is treated as presentational.
     // elements.img.attributesDefault = [{name: 'alt', value: ''}];
 
+    // By default,
+    // - padd the text inline element if it is empty and also a child of an empty root block
+    // - in all other cases, remove the text inline element if it is empty
+    each(textInlineElementsMap, (_val, name) => {
+      if (elements[name]) {
+        if (settings.padd_empty_block_inline_children) {
+          elements[name].paddInEmptyBlock = true;
+        }
+        elements[name].removeEmpty = true;
+      }
+    });
+
     // Remove these if they are empty by default
-    each(split('ol ul sub sup blockquote span font a table tbody strong em b i'), (name) => {
+    each(split('ol ul blockquote a table tbody'), (name) => {
       if (elements[name]) {
         elements[name].removeEmpty = true;
       }
@@ -866,7 +893,7 @@ const Schema = (settings?: SchemaSettings): Schema => {
    * @method getValidStyles
    * @type Object
    */
-  const getValidStyles = (): SchemaMap => validStyles;
+  const getValidStyles = Fun.constant(validStyles);
 
   /**
    * Name/value map object with valid styles for each element.
@@ -874,7 +901,7 @@ const Schema = (settings?: SchemaSettings): Schema => {
    * @method getInvalidStyles
    * @type Object
    */
-  const getInvalidStyles = (): SchemaMap => invalidStyles;
+  const getInvalidStyles = Fun.constant(invalidStyles);
 
   /**
    * Name/value map object with valid classes for each element.
@@ -882,7 +909,7 @@ const Schema = (settings?: SchemaSettings): Schema => {
    * @method getValidClasses
    * @type Object
    */
-  const getValidClasses = (): SchemaMap => validClasses;
+  const getValidClasses = Fun.constant(validClasses);
 
   /**
    * Returns a map with boolean attributes.
@@ -890,7 +917,7 @@ const Schema = (settings?: SchemaSettings): Schema => {
    * @method getBoolAttrs
    * @return {Object} Name/value lookup map for boolean attributes.
    */
-  const getBoolAttrs = (): SchemaMap => boolAttrMap;
+  const getBoolAttrs = Fun.constant(boolAttrMap);
 
   /**
    * Returns a map with block elements.
@@ -898,7 +925,7 @@ const Schema = (settings?: SchemaSettings): Schema => {
    * @method getBlockElements
    * @return {Object} Name/value lookup map for block elements.
    */
-  const getBlockElements = (): SchemaMap => blockElementsMap;
+  const getBlockElements = Fun.constant(blockElementsMap);
 
   /**
    * Returns a map with text block elements. For example: <code>&#60;p&#62;</code>, <code>&#60;h1&#62;</code> to <code>&#60;h6&#62;</code>, <code>&#60;div&#62;</code> or <code>&#60;address&#62;</code>.
@@ -906,7 +933,7 @@ const Schema = (settings?: SchemaSettings): Schema => {
    * @method getTextBlockElements
    * @return {Object} Name/value lookup map for block elements.
    */
-  const getTextBlockElements = (): SchemaMap => textBlockElementsMap;
+  const getTextBlockElements = Fun.constant(textBlockElementsMap);
 
   /**
    * Returns a map of inline text format nodes. For example: <code>&#60;strong&#62;</code>, <code>&#60;span&#62;</code> or <code>&#60;ins&#62;</code>.
@@ -914,7 +941,7 @@ const Schema = (settings?: SchemaSettings): Schema => {
    * @method getTextInlineElements
    * @return {Object} Name/value lookup map for text format elements.
    */
-  const getTextInlineElements = (): SchemaMap => textInlineElementsMap;
+  const getTextInlineElements = Fun.constant(textInlineElementsMap);
 
   /**
    * Returns a map with short ended elements. For example: <code>&#60;br&#62;</code> or <code>&#60;img&#62;</code>.
@@ -922,7 +949,7 @@ const Schema = (settings?: SchemaSettings): Schema => {
    * @method getShortEndedElements
    * @return {Object} Name/value lookup map for short ended elements.
    */
-  const getShortEndedElements = (): SchemaMap => shortEndedElementsMap;
+  const getShortEndedElements = Fun.constant(shortEndedElementsMap);
 
   /**
    * Returns a map with self closing tags. For example: <code>&#60;li&#62;</code>.
@@ -930,7 +957,7 @@ const Schema = (settings?: SchemaSettings): Schema => {
    * @method getSelfClosingElements
    * @return {Object} Name/value lookup map for self closing tags elements.
    */
-  const getSelfClosingElements = (): SchemaMap => selfClosingElementsMap;
+  const getSelfClosingElements = Fun.constant(selfClosingElementsMap);
 
   /**
    * Returns a map with elements that should be treated as contents regardless if it has text
@@ -939,7 +966,7 @@ const Schema = (settings?: SchemaSettings): Schema => {
    * @method getNonEmptyElements
    * @return {Object} Name/value lookup map for non empty elements.
    */
-  const getNonEmptyElements = (): SchemaMap => nonEmptyElementsMap;
+  const getNonEmptyElements = Fun.constant(nonEmptyElementsMap);
 
   /**
    * Returns a map with elements that the caret should be moved in front of after enter is
@@ -948,7 +975,7 @@ const Schema = (settings?: SchemaSettings): Schema => {
    * @method getMoveCaretBeforeOnEnterElements
    * @return {Object} Name/value lookup map for elements to place the caret in front of.
    */
-  const getMoveCaretBeforeOnEnterElements = (): SchemaMap => moveCaretBeforeOnEnterElementsMap;
+  const getMoveCaretBeforeOnEnterElements = Fun.constant(moveCaretBeforeOnEnterElementsMap);
 
   /**
    * Returns a map with elements where white space is to be preserved. For example: <code>&#60;pre&#62;</code> or <code>&#60;script&#62;</code>.
@@ -956,17 +983,20 @@ const Schema = (settings?: SchemaSettings): Schema => {
    * @method getWhiteSpaceElements
    * @return {Object} Name/value lookup map for white space elements.
    */
-  const getWhiteSpaceElements = (): SchemaMap => whiteSpaceElementsMap;
+  const getWhiteSpaceElements = Fun.constant(whiteSpaceElementsMap);
 
   /**
    * Returns a map with special elements. These are elements that needs to be parsed
    * in a special way such as script, style, textarea etc. The map object values
    * are regexps used to find the end of the element.
+   * <br>
+   * <em>Deprecated in TinyMCE 5.10 and has been marked for removal in TinyMCE 6.0</em>.
    *
    * @method getSpecialElements
+   * @deprecated
    * @return {Object} Name/value lookup map for special elements.
    */
-  const getSpecialElements = (): SchemaRegExpMap => specialElements;
+  const getSpecialElements = Fun.constant(specialElements);
 
   /**
    * Returns true/false if the specified element and it's child is valid or not
@@ -1037,7 +1067,7 @@ const Schema = (settings?: SchemaSettings): Schema => {
    * @method getCustomElements
    * @return {Object} Name/value map object of all custom elements.
    */
-  const getCustomElements = (): SchemaMap => customElementsMap;
+  const getCustomElements = Fun.constant(customElementsMap);
 
   /**
    * Parses a valid elements string and adds it to the schema. The valid elements
