@@ -5,7 +5,9 @@
  * For commercial licenses see https://www.tiny.cloud/
  */
 
-const applyListFormat = (editor, listName, styleValue) => {
+import Editor from 'tinymce/core/api/Editor';
+
+const applyListFormat = (editor: Editor, listName: string, styleValue: false | string): void => {
   const cmd = listName === 'UL' ? 'InsertUnorderedList' : 'InsertOrderedList';
   editor.execCommand(cmd, false, styleValue === false ? null : { 'list-style-type': styleValue });
 };
