@@ -5,12 +5,12 @@
  * For commercial licenses see https://www.tiny.cloud/
  */
 
-const isCodeSample = (elm: Element) => {
+const isCodeSample = (elm: Element | null): boolean => {
   return elm && elm.nodeName === 'PRE' && elm.className.indexOf('language-') !== -1;
 };
 
 const trimArg = <T>(predicateFn: (a: T) => boolean) => {
-  return (arg1: any, arg2: T) => {
+  return (arg1: unknown, arg2: T): boolean => {
     return predicateFn(arg2);
   };
 };
