@@ -7,9 +7,11 @@
 
 import Editor from 'tinymce/core/api/Editor';
 
-const getInline = (editor: Editor) => editor.getParam('inline');
+const getInline = (editor: Editor): boolean =>
+  editor.getParam('inline');
 
-const getFullscreenNative = (editor: Editor) => editor.getParam('fullscreen_native', false, 'boolean');
+const getFullscreenNative = (editor: Editor): boolean =>
+  editor.getParam('fullscreen_native', false, 'boolean');
 
 export {
   getInline,
