@@ -6,10 +6,11 @@
  */
 
 import Editor from 'tinymce/core/api/Editor';
+
 import * as Settings from '../api/Settings';
 import * as Actions from '../core/Actions';
 
-const register = (editor: Editor) => {
+const register = (editor: Editor): void => {
   editor.ui.registry.addContextToolbar('imagetools', {
     items: Settings.getToolbarItems(editor),
     predicate: (elem) => Actions.getEditableImage(editor, elem).isSome(),
