@@ -5,16 +5,18 @@
  * For commercial licenses see https://www.tiny.cloud/
  */
 
+import Editor from 'tinymce/core/api/Editor';
+
 import * as Actions from '../core/Actions';
 import * as Settings from './Settings';
 
-const register = (editor) => {
-  editor.addCommand('mceInsertDate', () => {
-    Actions.insertDateTime(editor, Settings.getDateFormat(editor));
+const register = (editor: Editor): void => {
+  editor.addCommand('mceInsertDate', (_ui, value) => {
+    Actions.insertDateTime(editor, value ?? Settings.getDateFormat(editor));
   });
 
-  editor.addCommand('mceInsertTime', () => {
-    Actions.insertDateTime(editor, Settings.getTimeFormat(editor));
+  editor.addCommand('mceInsertTime', (_ui, value) => {
+    Actions.insertDateTime(editor, value ?? Settings.getTimeFormat(editor));
   });
 };
 
