@@ -5,13 +5,13 @@
  * For commercial licenses see https://www.tiny.cloud/
  */
 
-const getTabFocusElements = (editor) => {
-  return editor.getParam('tabfocus_elements', ':prev,:next');
-};
+import Editor from 'tinymce/core/api/Editor';
 
-const getTabFocus = (editor) => {
-  return editor.getParam('tab_focus', getTabFocusElements(editor));
-};
+const getTabFocusElements = (editor: Editor): string =>
+  editor.getParam('tabfocus_elements', ':prev,:next');
+
+const getTabFocus = (editor: Editor): string =>
+  editor.getParam('tab_focus', getTabFocusElements(editor));
 
 export {
   getTabFocus
